import axios from "axios";
import { result } from "lodash";
import { resolve, reject } from "core-js/fn/promise";

export default {
  namespaced: true,
  state: {
    order: {},
    orders: [],
    orderItems: []
  },
  mutations: {
    setOrder(state, order) {
      state.order = order;
    },
    setOrders(state, orders) {
      state.orders = orders;
    },
    setOrderItems(state, items) {
      state.orderItems = items;
    },
    updateAddress(state, address) {
      state.order.deliveryAddress = address;
    }
  },
  getters: {},
  actions: {
    getOrder({ commit }, id) {
      axios.get(`/api/order/${id}`).then(result => commit("setOrder", result.data));
    },
    getUserOrders({ commit }, userId) {
      axios
        .get(`/api/order/GetUserOrders/${userId}`)
        .then(result => commit("setOrders", result.data));
    },
    getUserOrder({ commit }, userId) {
      axios
        .get(`/api/order/GetUserOrder/${userId}`)
        .then(result => commit("setOrder", result.data));
    },
    getRestaurantOrders({ commit }, restaurantId) {
      axios
        .get(`/api/order/GetRestaurantOrders/${restaurantId}`)
        .then(result => commit("setOrders", result.data));
    },
    getOrderItems({ commit }, orderId) {
      axios
        .get(`/api/order/GetOrderItems/${orderId}`)
        .then(result => commit("setOrderItems", result.data));
    },
    getCartOrder({ commit }, id) {
      axios.get(`/api/order/GetCartOrder/${id}`).then(result => commit("setOrder", result.data));
    },
    saveOrder({ commit }, order) {
      return new Promise((resolve, reject) => {
        axios
          .post("/api/order", order)
          .then(result => {
            commit("setOrder", result.data);
            resolve();
          })
          .catch(error => reject(new Error(error.message)));
      });
    },
    updateOrder({ commit }, order) {
      axios.put("/api/order", order).then(result => commit("setOrder", result.data));
    },
    updateAddress({ commit }, address) {
      return new Promise((resolve, reject) => {
        axios
          .put("/api/order/UpdateAddress", address)
          .then(result => {
            commit("updateAddress", result.data);
            resolve();
          })
          .catch(error => reject(new Error(error.message)));
      });
    }
  }
};
